==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_da_DK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da_DK">
<context>
    <name>RazorTaskButton</name>
    <message>
        <location filename="../razortaskbutton.cpp" line="372"/>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="405"/>
        <source>To &amp;Desktop</source>
        <translation>Til &amp;Skrivebord</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="407"/>
        <source>&amp;All Desktops</source>
        <translation>A&amp;lle Skriveborde</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="415"/>
        <source>Desktop &amp;%1</source>
        <translation>Skrivebord &amp;%1</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="422"/>
        <source>&amp;To Current Desktop</source>
        <translation>Til Nuværende Skrivebor&amp;d</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="431"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ksimer</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="440"/>
        <source>Maximize vertically</source>
        <translation>Maksimer vertikalt</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="445"/>
        <source>Maximize horizontally</source>
        <translation>Maksimer horisontalt</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="451"/>
        <source>&amp;Restore</source>
        <translation>&amp;Gendan</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="455"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimer</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="461"/>
        <source>Roll down</source>
        <translation>Rul ned</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="467"/>
        <source>Roll up</source>
        <translation>Rul op</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="476"/>
        <source>&amp;Layer</source>
        <translation>&amp;Lag</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="478"/>
        <source>Always on &amp;top</source>
        <translation>Altid &amp;Ovenpå</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="483"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="488"/>
        <source>Always on &amp;bottom</source>
        <translation>Altid Ned&amp;erst</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="496"/>
        <source>&amp;Close</source>
        <translation>&amp;Afslut</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="14"/>
        <source>Razor Task Manager Settings</source>
        <translation>Razor Jobliste Indstillinger</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="20"/>
        <source>Window List Content</source>
        <translation>Indhold Af Vinduesliste</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="26"/>
        <source>Show windows from current desktop</source>
        <translation>Vis vinduer fra nuværende skrivebord</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="29"/>
        <location filename="../razortaskbarconfiguration.ui" line="39"/>
        <source>wlcB</source>
        <translation>wlcB</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all desktops</source>
        <translation>Vis vinduer fra alle skriveborde</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="49"/>
        <source>Window List Appearance</source>
        <translation>Udseende af vinduesliste</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="55"/>
        <source>Button style</source>
        <translation>Knap stil</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="65"/>
        <source>Max button width</source>
        <translation>Maks. knapbredde</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="43"/>
        <source>Icon and text</source>
        <translation>Ikon og tekst</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="44"/>
        <source>Only icon</source>
        <translation>Kun ikoner</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="45"/>
        <source>Only text</source>
        <translation>Kun tekst</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Til &amp;Skrivebord</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>A&amp;lle Skriveborde</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>Skrivebord &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>Til Nuværende Skrivebor&amp;d</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ksimer</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Maksimer vertikalt</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Maksimer horisontalt</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Gendan</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimer</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Rul ned</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Rul op</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>&amp;Lag</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Altid &amp;Ovenpå</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Altid Ned&amp;erst</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Afslut</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Razor Jobliste Indstillinger</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Indhold Af Vinduesliste</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>Vis vinduer fra nuværende skrivebord</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Vis vinduer fra alle skriveborde</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Udseende af vinduesliste</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Knap stil</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Maks. knapbredde</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation>Luk ved midterklik</translation>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Ikon og tekst</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Kun ikoner</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Kun tekst</translation>
    </message>
</context>
</TS>
